==> usplash-theme-ubuntustudio_0.15.tar.gz: usplash-theme-ubuntustudio-0.15/ubuntustudio-theme-vars.h <==
/* y=up/down x=left/right */
/* Variables global to all resolutions. */
#define USPLASH_BACKGROUND 0 /* background colour */
#define USPLASH_PROGRESSBAR_BACKGROUND 164 /* Progress bar background colour */
#define USPLASH_PROGRESSBAR_FOREGROUND 853 /* Progress bar foreground colour */
#define USPLASH_TEXT_BACKGROUND 0 /* Text background colour */
#define USPLASH_TEXT_FOREGROUND 1181 //48607 /* Text foreground colour */
#define USPLASH_TEXT_SUCCESS 33840 /* Text colour for success message */
#define USPLASH_TEXT_FAILURE 59392 /* Text colour for failure message */

/* 640x400 */
#define USPLASH_640_400_PROGRESSBAR_X 230 /* X coordinate for the progress bar */
#define USPLASH_640_400_PROGRESSBAR_Y 275 /* Y coordinate for the progress bar */
#define USPLASH_640_400_PROGRESSBAR_WIDTH 216 /* Progress bar width */
#define USPLASH_640_400_PROGRESSBAR_HEIGHT 8 /* Progress bar height */
#define USPLASH_640_400_TEXT_X 140 /* Text box X coordinate */
#define USPLASH_640_400_TEXT_Y 305 /* Text box Y coordinate */
#define USPLASH_640_400_TEXT_WIDTH 360 /* Text box width */
#define USPLASH_640_400_TEXT_HEIGHT 75 /* Text box height */
#define USPLASH_640_400_LINE_HEIGHT 15 /* Text line height */
#define USPLASH_640_400_LINE_LENGTH 32 /* Text line length */
#define USPLASH_640_400_STATUS_WIDTH 35 /* Status text width */

/* Variables below are similar to those above, but for respective resolutions. */
/* 640x480 */
#define USPLASH_640_480_PROGRESSBAR_X 230
#define USPLASH_640_480_PROGRESSBAR_Y 355
#define USPLASH_640_480_PROGRESSBAR_WIDTH 216
#define USPLASH_640_480_PROGRESSBAR_HEIGHT 8
#define USPLASH_640_480_TEXT_X 140
#define USPLASH_640_480_TEXT_Y 385
#define USPLASH_640_480_TEXT_WIDTH 360
#define USPLASH_640_480_TEXT_HEIGHT 75
#define USPLASH_640_480_LINE_HEIGHT 15
#define USPLASH_640_480_LINE_LENGTH 32
#define USPLASH_640_480_STATUS_WIDTH 35

/* 800x600 */
#define USPLASH_800_600_PROGRESSBAR_X 300
#define USPLASH_800_600_PROGRESSBAR_Y 440
#define USPLASH_800_600_PROGRESSBAR_WIDTH 216
#define USPLASH_800_600_PROGRESSBAR_HEIGHT 8
#define USPLASH_800_600_TEXT_X 220
#define USPLASH_800_600_TEXT_Y 470
#define USPLASH_800_600_TEXT_WIDTH 360
#define USPLASH_800_600_TEXT_HEIGHT 75
#define USPLASH_800_600_LINE_HEIGHT 15
#define USPLASH_800_600_LINE_LENGTH 32
#define USPLASH_800_600_STATUS_WIDTH 35

/* 1024x768 */
#define USPLASH_1024_768_PROGRESSBAR_X 410
#define USPLASH_1024_768_PROGRESSBAR_Y 545
#define USPLASH_1024_768_PROGRESSBAR_WIDTH 216
#define USPLASH_1024_768_PROGRESSBAR_HEIGHT 8
#define USPLASH_1024_768_TEXT_X 332
#define USPLASH_1024_768_TEXT_Y 575
#define USPLASH_1024_768_TEXT_WIDTH 360
#define USPLASH_1024_768_TEXT_HEIGHT 75
#define USPLASH_1024_768_LINE_HEIGHT 15
#define USPLASH_1024_768_LINE_LENGTH 32
#define USPLASH_1024_768_STATUS_WIDTH 35

/* 1365x768 */
#define USPLASH_1365_768_PROGRESSBAR_X 600
#define USPLASH_1365_768_PROGRESSBAR_Y 500
#define USPLASH_1365_768_PROGRESSBAR_WIDTH 216
#define USPLASH_1365_768_PROGRESSBAR_HEIGHT 8
#define USPLASH_1365_768_TEXT_X 502
#define USPLASH_1365_768_TEXT_Y 530
#define USPLASH_1365_768_TEXT_WIDTH 360
#define USPLASH_1365_768_TEXT_HEIGHT 75
#define USPLASH_1365_768_LINE_HEIGHT 15
#define USPLASH_1365_768_LINE_LENGTH 32
#define USPLASH_1365_768_STATUS_WIDTH 35

==> usplash-theme-ubuntustudio_0.18.tar.gz: usplash-theme-ubuntustudio-0.18/ubuntustudio-theme-vars.h <==
/* y=up/down x=left/right */
/* Variables global to all resolutions. */
#define USPLASH_BACKGROUND 0 /* background colour */
#define USPLASH_PROGRESSBAR_BACKGROUND 32 /* Progress bar background colour */
#define USPLASH_PROGRESSBAR_FOREGROUND 131 /* Progress bar foreground colour */
#define USPLASH_TEXT_BACKGROUND 0 /* Text background colour */
#define USPLASH_TEXT_FOREGROUND 131 /* Text foreground colour */
#define USPLASH_TEXT_SUCCESS 131 /* Text colour for success message */
#define USPLASH_TEXT_FAILURE 189 /* Text colour for failure message */

/* 640x400 */
#define USPLASH_640_400_PROGRESSBAR_X 230 /* X coordinate for the progress bar */
#define USPLASH_640_400_PROGRESSBAR_Y 275 /* Y coordinate for the progress bar */
#define USPLASH_640_400_PROGRESSBAR_WIDTH 216 /* Progress bar width */
#define USPLASH_640_400_PROGRESSBAR_HEIGHT 8 /* Progress bar height */
#define USPLASH_640_400_TEXT_X 140 /* Text box X coordinate */
#define USPLASH_640_400_TEXT_Y 305 /* Text box Y coordinate */
#define USPLASH_640_400_TEXT_WIDTH 360 /* Text box width */
#define USPLASH_640_400_TEXT_HEIGHT 75 /* Text box height */
#define USPLASH_640_400_LINE_HEIGHT 15 /* Text line height */
#define USPLASH_640_400_LINE_LENGTH 32 /* Text line length */
#define USPLASH_640_400_STATUS_WIDTH 35 /* Status text width */

/* Variables below are similar to those above, but for respective resolutions. */
/* 640x480 */
#define USPLASH_640_480_PROGRESSBAR_X 230
#define USPLASH_640_480_PROGRESSBAR_Y 355
#define USPLASH_640_480_PROGRESSBAR_WIDTH 216
#define USPLASH_640_480_PROGRESSBAR_HEIGHT 8
#define USPLASH_640_480_TEXT_X 140
#define USPLASH_640_480_TEXT_Y 385
#define USPLASH_640_480_TEXT_WIDTH 360
#define USPLASH_640_480_TEXT_HEIGHT 75
#define USPLASH_640_480_LINE_HEIGHT 15
#define USPLASH_640_480_LINE_LENGTH 32
#define USPLASH_640_480_STATUS_WIDTH 35

/* 800x600 */
#define USPLASH_800_600_PROGRESSBAR_X 300
#define USPLASH_800_600_PROGRESSBAR_Y 440
#define USPLASH_800_600_PROGRESSBAR_WIDTH 216
#define USPLASH_800_600_PROGRESSBAR_HEIGHT 8
#define USPLASH_800_600_TEXT_X 220
#define USPLASH_800_600_TEXT_Y 470
#define USPLASH_800_600_TEXT_WIDTH 360
#define USPLASH_800_600_TEXT_HEIGHT 75
#define USPLASH_800_600_LINE_HEIGHT 15
#define USPLASH_800_600_LINE_LENGTH 32
#define USPLASH_800_600_STATUS_WIDTH 35

/* 1024x768 */
#define USPLASH_1024_768_PROGRESSBAR_X 410
#define USPLASH_1024_768_PROGRESSBAR_Y 545
#define USPLASH_1024_768_PROGRESSBAR_WIDTH 216
#define USPLASH_1024_768_PROGRESSBAR_HEIGHT 8
#define USPLASH_1024_768_TEXT_X 332
#define USPLASH_1024_768_TEXT_Y 575
#define USPLASH_1024_768_TEXT_WIDTH 360
#define USPLASH_1024_768_TEXT_HEIGHT 75
#define USPLASH_1024_768_LINE_HEIGHT 15
#define USPLASH_1024_768_LINE_LENGTH 32
#define USPLASH_1024_768_STATUS_WIDTH 35

/* 1365x768 */
#define USPLASH_1365_768_PROGRESSBAR_X 600
#define USPLASH_1365_768_PROGRESSBAR_Y 500
#define USPLASH_1365_768_PROGRESSBAR_WIDTH 216
#define USPLASH_1365_768_PROGRESSBAR_HEIGHT 8
#define USPLASH_1365_768_TEXT_X 502
#define USPLASH_1365_768_TEXT_Y 530
#define USPLASH_1365_768_TEXT_WIDTH 360
#define USPLASH_1365_768_TEXT_HEIGHT 75
#define USPLASH_1365_768_LINE_HEIGHT 15
#define USPLASH_1365_768_LINE_LENGTH 32
#define USPLASH_1365_768_STATUS_WIDTH 35
